@@ -1,5 +1,5 @@
 /*
-  $Id: Logging.h 13843 2012-01-02 16:34:06Z sloot $
+  $Id: Logging.h 15273 2012-10-10 12:26:42Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Mbt3/include/mbt/Logging.h $
 
   Copyright (c) 1998 - 2012
@@ -27,19 +27,18 @@
       timbl@uvt.nl
 */
 
-#ifndef LOGGING_H
-#define LOGGING_H
+#ifndef MBT_LOGGING_H
+#define MBT_LOGGING_H
 
-#include "timbl/LogStream.h"
-
-extern LogStream default_log;
-extern LogStream *cur_log;
-
-#define LOG (*Log(cur_log))
-#define DBG (*Dbg(cur_log))
-#define xDBG (*xDbg(cur_log))
-#define xxDBG (*xxDbg(cur_log))
+#include "ticcutils/LogStream.h"
 
+extern TiCC::LogStream default_log;
+extern TiCC::LogStream *cur_log;
 extern LogLevel Tagger_Log_Level;
 
+#define LOG (*TiCC::Log(cur_log))
+#define DBG (*TiCC::Dbg(cur_log))
+#define xDBG (*TiCC::xDbg(cur_log))
+#define xxDBG (*TiCC::xxDbg(cur_log))
+
 #endif // LOGGING_H
