@@ -1,5 +1,5 @@
 /*
-  $Id: MbtAPI.h 14374 2012-03-05 11:13:09Z sloot $
+  $Id: MbtAPI.h 15061 2012-08-08 08:47:53Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Mbt3/include/mbt/MbtAPI.h $
 
   Copyright (c) 1998 - 2012
@@ -31,10 +31,11 @@
 #define MBT_API_H
 
 #include "timbl/TimblAPI.h"
-#include "timbl/LogStream.h"
+#include "ticcutils/LogStream.h"
 #include "mbt/Tagger.h"
 
 using namespace Timbl;
+using namespace TiCC;
 using namespace Tagger;
 
 class MbtAPI {
@@ -44,7 +45,7 @@ class MbtAPI {
   static bool GenerateTagger( const std::string& );
   static bool RunTagger( int, char** );
   MbtAPI( const std::string& );
-  MbtAPI( const std::string&, LogStream& );
+  MbtAPI( const std::string&, TiCC::LogStream& );
   ~MbtAPI();
   bool isInit() const;
   std::string Tag( const std::string& );
