@@ -1,5 +1,5 @@
 /*
-  $Id: Pattern.h 13843 2012-01-02 16:34:06Z sloot $
+  $Id: Pattern.h 15273 2012-10-10 12:26:42Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Mbt3/include/mbt/Pattern.h $
 
   Copyright (c) 1998 - 2012
@@ -26,8 +26,8 @@
   or send mail to:
       timbl@uvt.nl
 */
-#ifndef PATTERN_H
-#define PATTERN_H
+#ifndef MBT_PATTERN_H
+#define MBT_PATTERN_H
 
 class PatTemplate {
  public:
