@@ -1,5 +1,5 @@
 /*
-  $Id: Sentence.h 14420 2012-03-07 16:54:30Z sloot $
+  $Id: Sentence.h 15273 2012-10-10 12:26:42Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Mbt3/include/mbt/Sentence.h $
 
   Copyright (c) 1998 - 2012
@@ -26,10 +26,10 @@
   or send mail to:
       timbl@uvt.nl
 */
-#ifndef SENTENCE_H
-#define SENTENCE_H
+#ifndef MBT_SENTENCE_H
+#define MBT_SENTENCE_H
 
-#include "timbl/Tree.h"
+#include "ticcutils/TreeHash.h"
 
 namespace Tagger {
   using Hash::Lexicon;
