@@ -1,5 +1,5 @@
 /*
-  $Id: TagLex.h 13843 2012-01-02 16:34:06Z sloot $
+  $Id: TagLex.h 15273 2012-10-10 12:26:42Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Mbt3/include/mbt/TagLex.h $
 
   Copyright (c) 1998 - 2012
@@ -26,10 +26,10 @@
   or send mail to:
       timbl@uvt.nl
 */
-#ifndef TAGLEX_H
-#define TAGLEX_H
+#ifndef MBT_TAGLEX_H
+#define MBT_TAGLEX_H
 
-#include "timbl/Trie.h"
+#include "ticcutils/Trie.h"
 #include "timbl/Common.h"
 
 namespace Tagger {
