@@ -1,5 +1,5 @@
 /*
-  $Id: Tagger.h 14402 2012-03-07 14:04:57Z sloot $
+  $Id: Tagger.h 15273 2012-10-10 12:26:42Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Mbt3/include/mbt/Tagger.h $
 
   Copyright (c) 1998 - 2012
@@ -26,8 +26,8 @@
   or send mail to:
       timbl@uvt.nl
 */
-#ifndef TAGGER_H
-#define TAGGER_H
+#ifndef MBT_TAGGER_H
+#define MBT_TAGGER_H
 
 #include "mbt/Pattern.h"
 #include "mbt/Sentence.h"
@@ -101,15 +101,15 @@ namespace Tagger {
     bool parse_run_args( Timbl::TimblOpts& Opts, bool = false );
     bool isClone() const { return cloned; };
     void ShowCats( std::ostream& os, const std::vector<int>& Pat, int slots );
-    bool setLog( LogStream& );
+    bool setLog( TiCC::LogStream& );
     int ProcessLines( std::istream&, std::ostream& );
     void read_lexicon( const std::string& );
     void read_listfile( const std::string&, StringHash * );
-    static TaggerClass *StartTagger( Timbl::TimblOpts&, LogStream* = 0 );
+    static TaggerClass *StartTagger( Timbl::TimblOpts&, TiCC::LogStream* = 0 );
     static int CreateTagger( Timbl::TimblOpts& );
     bool isInit() const { return initialized; };
   private:
-    LogStream *cur_log;
+    TiCC::LogStream *cur_log;
     Timbl::TimblAPI *KnownTree;
     Timbl::TimblAPI *unKnownTree;
     std::string Timbl_Options;
