@@ -1,5 +1,5 @@
 /*
-  $Id: Sentence.cxx 14420 2012-03-07 16:54:30Z sloot $
+  $Id: Sentence.cxx 15273 2012-10-10 12:26:42Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Mbt3/src/Sentence.cxx $
 
   Copyright (c) 1998 - 2012
@@ -36,14 +36,12 @@
 #include <cctype>
 #include <cassert>
 
-#include "timbl/StringOps.h"
-#include "timbl/Tree.h"
+#include "ticcutils/StringOps.h"
 #include "mbt/Pattern.h"
 #include "mbt/Sentence.h"
 
 namespace Tagger {
   using namespace Hash;
-  using namespace Timbl;
   using namespace std;
  
   const string Separators = "\t \n";
@@ -493,7 +491,7 @@ namespace Tagger {
     while( not_ready && infile ) {
       getline( infile, linebuffer );
       infile >> ws;
-      size_t size = split( linebuffer, extras );
+      size_t size = TiCC::split( linebuffer, extras );
       if ( size == 1 && Utt_Terminator( extras.front() ) ){
 	// Word = extras.front();
 	// add( Word, "" );
